@@ -23,7 +23,9 @@ class APIFunction(LambdaFunction):
             response = self.put(event, context, *args)
 
         elif method == "options":
+            print("Returning options payload:")
             response = self.create_return()
+            print(response)
 
         else:
             raise Exception(f"Triggered with unexpected HTTP method {method}.")
@@ -35,7 +37,7 @@ class APIFunction(LambdaFunction):
         headers = {
             "Access-Control-Allow-Origin": "*",
             "Access-Control-Allow-Credentials": "true",
-            "Access-Control-Allow-Headers": "Authorization",
+            "Access-Control-Allow-Headers": "Authorization,Content-Type",
             "Access-Control-Allow-Methods": "*",
         }
         return_obj["headers"] = headers
